import java.io.*;
import java.nio.charset.Charset;
import org.junit.*;

/** JUnit-Test fuer EncodingGuess */
public class EncodingGuessTest
{
   private static final String[] ENCODINGS1 = { "US-ASCII", "ISO-8859-1", "windows-1252", "UTF-8", "UTF-16BE", "UTF-16LE" };
   private static final String[] ENCODINGS2 = { "UTF-8", "UTF-16BE", "UTF-16LE" };
   private static final String   MEIN_TEXT1 = "BlaBlupp\r\n\u20AC"; // \u20AC = Euro-Zeichen
   private static final String   MEIN_TEXT2 = "\uFEFF abc";             // \uFEFF = BOM

   @Test
   public void testEncodingGuessFromFile() throws IOException
   {
      // Vor Ausfuehrung Pfade anpassen:
      Assert.assertEquals( "US-ASCII",   EncodingGuess.guessEncodingFromFile( new File( "src/EncodingGuess.java"     ), false, false ) );
      Assert.assertEquals( "ISO-8859-1", EncodingGuess.guessEncodingFromFile( new File( "src/EncodingGuessTest.java" ), false, false ) );
   }

   @Test
   public void testEncodingGuessFromStream() throws IOException
   {
      // Encoding-Erkennung ohne BOM, anhand der verwendeten Zeichen:
      for( String enc : ENCODINGS1 ) {
         if( !Charset.availableCharsets().containsKey( enc ) ) { continue; }
         try( ByteArrayInputStream is1 = new ByteArrayInputStream( MEIN_TEXT1.getBytes( enc ) ) ) {
            Assert.assertEquals( enc, EncodingGuess.guessEncoding( is1, false, false ) );
         }
      }
      // Encoding-Erkennung mit BOM:
      for( String enc : ENCODINGS2 ) {
         try( ByteArrayInputStream is2 = new ByteArrayInputStream( MEIN_TEXT2.getBytes( enc ) ) ) {
            Assert.assertEquals( enc, EncodingGuess.guessEncoding( is2, false, false ) );
         }
      }
      // Bevorzuge ISO-8859-1 statt US-ASCII:
      try( ByteArrayInputStream is3 = new ByteArrayInputStream( MEIN_TEXT1.getBytes( "US-ASCII" ) ) ) {
         Assert.assertEquals( "ISO-8859-1", EncodingGuess.guessEncoding( is3 ) );
      }
   }

   @Test
   public void testHex() throws IOException
   {
      Assert.assertEquals( "426C61426C7570700D0AE4F6FCDF3F", EncodingGuess.toHexString( MEIN_TEXT1.getBytes( "ISO-8859-1" ), 0, 99 ) );
      Assert.assertEquals( "426C61426C7570700D0AC3A4C3B6C3BCC39FE282AC", EncodingGuess.toHexString( MEIN_TEXT1.getBytes( "UTF-8" ), 0, 99 ) );
   }
}
